#
# spec file for package libindi
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver 1
%define _udevdir %(pkg-config --variable udevdir udev)

Name:           libindi
Version:        1.7.1
Release:        lp150.1.2
Summary:        Instrument Neutral Distributed Interface
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Scientific/Astronomy
Url:            http://www.indilib.org/
Source0:        https://github.com/indilib/indi/releases/download/v%{version}/%{name}_%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gsl-devel
BuildRequires:  libcfitsio-devel
BuildRequires:  libcurl-devel
BuildRequires:  libfli-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libnova-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
Requires:       libindi-plugins = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package devel
Summary:        Development files for libindi
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libindiAlignmentDriver%{so_ver} = %{version}
Requires:       libindidriver%{so_ver} = %{version}

%description devel
This package contains development files for libindi.

%package plugins
Summary:        Plugins for libindi
Group:          Productivity/Scientific/Astronomy
# libindi1 was last used at version 1.3.1
Obsoletes:      libindi1 < %{version}

%description plugins
This package contains plugins for libindi.

%package -n libindiAlignmentDriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindiAlignmentDriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindidriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindidriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%prep
%setup -q -n %{name}

%build
mkdir build
cd build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
_libsuffix=$(echo %_lib | cut -b4-)
cmake \
 -DCMAKE_INSTALL_PREFIX=%{_prefix} \
 -DLIB_SUFFIX="$_libsuffix" \
 -DUDEVRULES_INSTALL_DIR=%{_udevdir}/rules.d \
 ..
make %{?_smp_mflags} VERBOSE=1
cd ..

%install
%cmake_install

%post -n libindiAlignmentDriver%{so_ver} -p /sbin/ldconfig

%postun -n libindiAlignmentDriver%{so_ver} -p /sbin/ldconfig

%post -n libindidriver%{so_ver} -p /sbin/ldconfig

%postun -n libindidriver%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license COPYING.* COPYRIGHT LICENSE
%doc AUTHORS ChangeLog NEWS README TODO
%{_datadir}/indi/
%{_bindir}/indi*
%{_udevdir}/rules.d/*.rules

%files devel
%defattr(-,root,root,-)
%license COPYING.GPL COPYING.LGPL LICENSE
%{_includedir}/libindi/
%{_libdir}/pkgconfig/libindi.pc
%{_libdir}/libindi*.so
%{_libdir}/libindi*.a

%files plugins
%defattr(-,root,root,-)
%license COPYING.GPL COPYING.LGPL LICENSE
%{_libdir}/indi/

%files -n libindiAlignmentDriver%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libindiAlignmentDriver.so.%{so_ver}*

%files -n libindidriver%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libindidriver.so.%{so_ver}*

%changelog
* Thu Apr 12 2018 wbauer@tmo.at
- Update to version 1.7.1:
  * Hotfix for INDI API version that was not updated properly to
    1.7.0 in the previous release
  * Fixes to Astrophysics driver
  * More code cleanup and refactoring
* Wed Apr 11 2018 wbauer@tmo.at
- Update to version 1.7.0:
  * Updated QHY SDK.
  * FLI drivers are now based on libusb rather than legacy kernel
    driver.
  * New driver for CEM120 mount.
  * New driver for Explore Scientific PMC8.
  * Several memory leaks were fixed.
  * Added support for background flushing for FLI CCDs.
  * Added preliminary support for CCD rapid captures on the
    millisecond range.
  * SX CCD driver updated to support ICX453 & M25C.
  * SX AO driver updated to emply INDI serial connection plugin.
  * Fix timing issue with GPhoto making it stuck in busy state
    after initial capture.
  * ASI driver enhancements. Video format recall fix.
  * MaxDomeII driver refactored and updated.
  * Several fixes for Gemini Integra driver.
  * Polling period for most drivers is now customizable.
  * GPhoto driver supported Abort exposure. Subframing fixes.
  * GPS driver can set system time from GPS source.
  * Astrophyics Experimental Driver with multi-parking support.
  * Numerous OnStep driver fixes and updates.
  * SkySensor2000 Pulse guiding support.
  * Prevent sandbox ACCESS_VIOLATION on Gentoo
  * Celestron driver refactoring and support for high-precision
    formats.
  * Fixed script execution in scripting gateways
  * Fix flags for Cygwin.
  * Fix non-standard POSIX C functions.
  * Replace deprecated usleep with nanosleep.
  * CCD & Telescope simulator updated so that can be used
    effectively in any combination with physical devices.
- Mark license files as %%license instead of %%doc
* Tue Jan  9 2018 wbauer@tmo.at
- Update to version 1.6.2:
  * Another quick release to fix missing cmake_modules directory
    and a joystick driver crash fix.
  From version 1.6.1:
  * This is a bugfix patch release that resolves problems with INDI
    version in INDI API.
  From version 1.6.0:
  * INDI Base Client is now supported on Windows, MacOS, and Linux.
  * Added 10Micron Mount support.
  * Added spectrum support and libDSPAU.
  * Added NexDome support.
  * Added Pyxis Rotator support.
  * Added Pegasus Focuser support.
  * Added MBox Weather box support.
  * Added SnapCap dust cap and flat panel support.
  * Added Sesto-Senso focuser support.
  * Added USB_DewPoint support.
  * Added GPS-NMEA sources support.
  * Added Gemini Telescope Design Integra85 Focusing Rotator WIP
    support.
  * Added Lunatico's Armadillo and Platypus support.
  * Video Streaming support for MacOS.
  * Video Recording with libtheora (Optional).
  * Video Streaming with MJPEG encoder.
  * IOptron fixes and improvements.
  * More NextstarEvo improvements.
  * Dedicated Guider Simulator.
  * QHY & ASI updated to latest SDK.
  * Apogee fixes for MacOS.
  * INova fixes and improvements. Updated SDK.
  * QHY, Apogee, DSI builds for MacOS.
  * EQMod Horizon fixes.
  * Skywatcher Alt-Az Mount & Syncscan fixes and improvements
    including guide support.
  * StarSense support in Celestron Driver.
  * Improvements to mount parking & unparking.
  * New experimental Astrophysics Driver.
  * Support for Losmandy UDP protocol.
  * Fixed Dome slaving slew and tracking.
  * Added Radio Antenna Simulator.
  * New INDI Rotator Interface.
  * UDEV rule to disable automount of DSLR cameras.
  * Sky Quality Meter simulator.
  * Improvements to INDI GPS drivers.
  * TCFS Fixes.
  * SkySensorPC2000 fixes.
  * Fixed WatchDog behavior in case of unavailable dome.
  * Improved Continuous Integration support with Travis & CircleCI
    using Docker.
- Drop cmake_modules.tar.gz, no longer necessary
* Thu Sep 21 2017 wbauer@tmo.at
- Update to version 1.5.0:
  * New Detector Interface for photon and radio detectors.
  * New Software-Defined-Radio driver (RTLSDR).
  * New Connections plugin system to facilitate driver development.
  * New standardized tracking properties system for all mounts.
  * New Digital Settings Circiles (DSC) driver.
  * New Lacerta MGen driver.
  * New NightCrawler Focusing Rotator driver.
  * New Optec Gemini Focusing Rotater driver.
  * New iNovaPLX CCD driver.
  * QHY SDK update to 1.10.0. Support for QHY PoleMaster.
  * QSI SDK update to 7.6.0
  * Support for INDI client under Windows.
  * Support for Pier Side in many mount drivers.
  * Support for SkySafari.
  * Fix FLIUSB for 4.6 and 4.9 kernels.
  * Fixed wrong time format in generated SER files.
  * ZWO ASI drivers for MacOS.
  * Various GPSD fixes.
  * Proper handing of ISO8601 timestamps in the generated
    filenames.
  * Improved Gemini mount driver with more functionality and bug
    fixes.
  * Many V4L2 fixes and improvements. Support for V4L2 integer
    menus.
  * Ability to define multiple primary/guide scope configurations.
  * ZEQ25 Improvements and fixes.
  * NStep driver improvements and fixes.
  * Added Ccache support.
  * Support for Gotonova driver.
  * Added Unity Build support.
  * Improved Astrophysics driver.
  * Added USB connectivity to SQM device driver.
  * More robust handling of reading pier side from mount.
  * Warn client that no devices are detected in case of
    Multiple-Devices-Per-Driver drivers.
  * Added PEC control to INDI::Telescope. Each driver must handle
    the low level protocol to actually enable or disable PEC.
  * Added security (hardening) flags.
  * SoftPEC implementation for Virtuoso mounts in
    skywatcherAPIMount.
  * Added TELESCOP, OBSERVER, and OBJECT keywords to the FITS
    header.
- Add cmake_modules.tar.gz containing cmake modules missing in the
  source tarball to make it build
- Drop bufferoverflow.patch, fixed upstream
* Wed Mar 15 2017 asterios.dramis@gmail.com
- Update to version 1.4.1:
  * Minor bugfix release to fix installation of development headers
    issue in 1.4.0.
  From version 1.4.0:
  * Support for HitecAstro DC Focuser.
  * Support for SQL-LE Sky Quality Meter unit.
  * Support for USB Focus V3.
  * Support for Quantum Filter Wheel.
  * Support for 10micron mounts.
  * ZWO ASI filter wheel support. Driver updated to latest SDK. Fix
    infinite loop exposure.
  * QHY driver updated to latest SDK.
  * Added preliminary support to TCP server connection for all
    mounts.
  * Updated and improved Nexstar Evo driver.
  * Fixed reset of filter wheel names to default values under some
    circumstances.
  * Fixed feedback loop issue in chained INDI server.
  * Handle correctly broken frames in FLI driver; convert time left
    from ms to seconds as it should be.
  * V4L2 CCD driver updated to properly work with DMK cameras.
  * Several bugfixes for Moravian CCD driver.
  * CCD Simulator allows for up to 4096x4096 resolution.
  * Raw color video streaming now uses RGB24 instead of RGBA to
    conserve bandwidth.
  * New Dome and Mount safety interlocks mechanism.
  * Fix the Virtuoso mount detection in SkyWatcherMountAPI driver.
  * Support relative driver paths to INDI server.
  * Fix property cache collision conflict in case of multiple
    devices per driver.
  * Moonlite driver can now sync to any value instead of reset to
    zero.
  * Store OBJECTRA and OBJECTDEC as sexigesimal strings.
  * New Axis Lock feature to limit joystick to specific motion
    axis.
  * INDI server now reaps zombie processes as they appear.
  * EQMod support for AUX encoder values. ST4 Guide Rates settings.
    PPEC Switches.
  * Fix for TELESCOPE_PIER_SIDE implementation in EQMod driver.
  * Several fixes for Pulsar2 driver.
  * Fix SER file generation for color frames. Added timestamps for
    each recorded frame. Support subframed video streams.
  * Debug and Logging options can be saved in the config file.
  * New CCD_TRANSFER_FORMAT property.
  * libindi can now be compiled under MacOS and Cygwin. Non-Linux
    specific 3rd party drivers are also supported under MacOS and
    Cygwin.
  * When a request for snooped is sent, it is echoed to drivers so
    that they send the snopped value immediately if it exists.
  * libindi shared library is dropped. libindi now offsers
    indidriver (shared), indiclient (static), and indiclientqt5
    (static) libraries.
  * Legacy drivers removed: SkyCommander, Intelliscope, MagellanI,
    TruTech, SBIG STV.
- Added new subpackage libindi-plugins.
- libindi1 was dropped from the package source. Obsolete it in
  libindi-plugins in order to fix conflicts due to %%{_libdir}/indi/
  previously contained in libindi1.
- Removed libindi-generate-tarball.sh script (not needed anymore).
- Removed no-return-in-nonvoid-function.patch (fixed upstream).
- Added a patch (bufferoverflow.patch) to fix "Statement is
  overflowing a buffer" post-build check errors.
* Sat Jan 21 2017 asterios.dramis@gmail.com
- Update to version 1.3.1:
  * Support for Optec IFW Filter Wheel.
  * Added new method in base client getBLOBMode to retrieve
    previously set BLOB mode for a device/property pair.
  * QHY driver use software binning by default for all cameras.
  * Minor bug fixes and improvements across all drivers.
  From version 1.3.0:
  * Support for Shelyak eShel spectrograph.
  * Support for NStep focuser.
  * Support for ASI Filter Wheel.
  * Support for OneStep Telescope Controller.
  * Support for Moravian CCD driver.
  * Support for  GigE machine vision cameras.
  * Experimental SSAG CCD driver.
  * Adding support for fast BLOB with ENCLEN. With Fast blob mode
    enabled, blob performance is now significantly faster.
  * FITS Min/Max calculations are disabled by default to save
    processing time unless explicitly enabled by the user at
    compile time.
  * Qt5 based client class is added to enable multiplatform client
    development.
  * New significantly faster base64 encoding/decoding routines.
  * Selectable alignment modes for INDI EQMod that includes
    built-in EQMod alignment and INDI Alignment Subsystem.
  * CCD sequence queue number is no longer limited to 999.
  * More Starlight Xpress CCDs cameras supported.
  * Updated Starlight Xpress Adaptive Optics driver.
  * Updated Temma Takahashi mount driver.
  * Updated Apogee CCD driver.
  * Updated QHY CCD driver with numerous fixes.
  * Updated FLI CCD driver.
  * Updated Pulasr2 driver.
  * Updated ASI CCD with support for arm64 architecture, 1600 model
    and a lot more.
  * Significant improvements to GPhoto driver including better
    support for Nikon DSLRs.
  * Improved GPSd driver.
  * New CCD_FILE_PATH property to indicate remote file path.
  * New TELESCOPE_PIER_SIDE property.
  * Dome & Telescope Scripting Gateway added.
  * Added support for servos in Indiduino
  * Fix BuiltinMathPlugin crash for Southern Hemisphere
  * Add scope park aware feature to the rolloff roof simulator
  * INDI Logs are now stored under ~/.indi/logs and arranged by
    date and time per driver.
- Removed support for openSUSE < 11.4.
- Added new build requirement Qt5Network.
- Removed libindi-implicit-pointer-decl.patch (fixed upstream).
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Starting with release 1.3 INDI ships libindi and 3rdparty stuff
  (drivers and external libraries, not necessary for libindi) in
  one big tar archive. The 3rdparty stuff cannot be installed
  without libindi already installed.
  Added a script "libindi-generate-tarball.sh" to generate a clean
  tarball containing only the library (based on one from Fedora).
* Sun Jun 26 2016 asterios.dramis@gmail.com
- Update to version 1.2.0:
  * Support for Davis Vantage Pro/Pro2/Vue Weather Station.
  * Support for XAGYL Filter Wheel.
  * Support for Optec Flip Flat.
  * Support for Pulasr2 mount.
  * Support for JMI Smart Focus.
  * Support for GPS driver based on gpsd.
  * 3rdParty: QHY Updates and Fixes. Color camera support.
  * 3rdParty: GPhoto focus and live streaming fixes.
  * 3rdParty: Starlight Xpress support for multiple identical
    devices and driver improvements.
  * 3rdParty: ASI updated to latest SDK. Temperature readout for
    all cameras. ROI & Cooler fixes.
  * FocusLynx: Support 2 focusers.
  * Celestron: Support pulse guiding. Support hibernation and wakup
    on supported firmware.
  * SynScan: Complete rewrite to support latest features in the
    firmware.
  * GPhoto: Mirror lock support before capture.
  * RoboFocus: Update to comply to INDI::Focus standards.
  * SBIG: Support for connecting to Ethernet based CCDs.
  * ZEQ25: Updates and fixes.
  * MaxDomeII: Driver updated and tested under latest INDI::Dome
    standards.
  * QSI: Added anti-blooming option.
  * INDI WatchDog driver: Can be configured to perform observatory
    shutdown.
  * EQMod: Initial support for INDI Alignment Subsystem. Do not
    stop motor in low speed (guiding issue).
  * Temma: Complete rewrite based on INDI::Telescope and using INDI
    Alignment Subsystem.
  * AutoDome park feature in Dome devices.
  * Fix Crash on ODroid.
  * Added Meta-Weather driver to aggregate weather data from
    multiple sources.
  * Support for remotely controller dust caps and light box devices.
  * Handle 16bit images in Rapid Guide mode.
  * BaseClient non-blocking connect support.
  * Unified Streaming/Recording support for multiple drivers
    (ASI/QHY/V4L2).
  From version 1.1.0:
  * INDI::Weather for support of weather devices.
  * INDI::GPS for support of GPS devices.
  * WunderGround weather driver.
  * Meade DSI I & II support.
  * FocusLynx focuser support.
  * PerfectStar focuser support.
  * World Coordinate System (WCS) support in generated FITS.
  * Updated Losmany driver.
  * New Celestron driver.
  * New IEQPro driver.
  * Support for custom parking in dome drivers.
  * Support Open Loop dome controllers.
  * Various QHY CCD & Filter Wheel fixes and QHY OSX support.
  * SBIG External Guide CCD fixes.
  * Custom parking support for
    Celestron/Astrophysics/AstroElectronics/IEQPro
  * Updated ASI ZWO drivers.
  * Updated Apogee library. Improved NET support in INDI Apogee
    driver.
  * Standarizing mount slew and track rates.
  * Video4Linux 2 fixes and improvements: (16bpp pixel formats(Y16
    and BYR2), pwc flashled, colorSpace/linearization, stacking),
    Simutaneous record/stream/exp. Stream rate divisor. Rec. file
    patterns.
  * EQMod fixes: Keep tracking after joystick motion is stopped.
    Park initialization always set encoders.
  * Improved support for drivers on ARM architecture.
  * Improved logging capability.
  * Deprecated: LX200Legacy and indimain library.
- Rebased libindi-implicit-pointer-decl.patch to apply cleanly.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Added new build requirement libcurl-devel.
* Sun Jul  5 2015 crrodriguez@opensuse.org
- libindi-implicit-pointer-decl.patch: fix rpmlint implicit
  declaration warnings
- BuildRequire libusb-1.0 not libusb-devel
- Build C++ code with at least -fvisibility-inlines-hidden.
* Sat Feb 21 2015 asterios.dramis@gmail.com
- Update to version 1.0.0:
  * 3rdparty: Support for QHY CCDs and CFWs (BETA).
  * 3rdparty: Support for Meade DSI (BETA).
  * 3rdparty: Support for FFMV cameras.
  * Support for STAR2000.
  * Support for Baader dome.
  * Support for Baader SteelDrive focuser.
  * Support for dome slaving (BETA).
  * Subframing and debayer support in GPhoto driver.
  * Improved CFW handling and external tracking CCD for SBIG CCDs.
  * Add debayer support for color cameras with user-configurable
    options. Debayer is performed at the client level.
  * Fixed deinterlacing and subframing support in Starlight Xpress
    drivers.
  * Fixed issues with joystick support in some drivers. Added
    joystick support to focuser and filter wheels.
  * Improvements in generation of FITS header.
  * Improvement in performance of some drivers under SBCs like
    Raspberry PI.
  * Added fan and readout speed controls to QSI CCD.
  * Fixed locale issue in INDI driver.
  * Fixed regression in LX200Basic driver.
  * Fixed issue with INDI Server resetting environment variable for
    skeleton and config files.
  * Various fixes for loading/saving of user configuration.
  From version 0.9.9:
  * Thread-safe INDI Library.
  * Support for Rigelsys NFocus Focuser driver.
  * 3rdparty: Additional VID/PID for QHY.
  * 3rdparty: added USB Bandiwdth control for ZWO Optical cameras.
  * 3rdparty: Updated and improved INDI Apogee driver and Apogee
    Library major update.
  * 3rdparty: Live preview support for GPhoto driver. Tested on
    Canon.
  * 3rdparty: Various bugfixes and improvements in INDI SBIG driver
    including working guide chip support.
  * 3rdparty: Fixed time drift error in EQMod. Added Horizon
    limits. Added Backlash comp.
  * Updated and improved Image Agent.
  * Improved Astrophysics driver support.
  * Fixed location bug in Celestron GPS driver.
  * Additional information in FITS header such as filter name.
  * Joystick support for focuser and filter wheel devices.
  * Added option to enable local & remote save for FITS images in
    all CCD drivers.
  * Older V4L driver is deprecated (indi_v4l_legacy) and is
    replaced by indi_v4l2_ccd
  * V4L2: added recording (SER files) for use with Registax
  * V4L2: added RGGB & UYVY pixel format support to V4L2 drivers.
  * V4L2: fixed LX long exposure times.
  * Updated and improved tutorials.
  * Fixed few OSX compatibility issues.
  * Various bug fixes and improvements.
  From version 0.9.8:
  * Support for Telescope Alignment Subsystem Infrastructure. This
    includes an implementation of Markley's singular value
    decomposition (SVD) based algorithm for the computation of
    sky/telescope coordinate conversion transforms, in addition to
    multiple plugin support.
  * Suppprt for SkyWatcherAPI Mount with Alignment Subsystem.
  * Support for ZWO Optics ASI Cameras (3rd party)
  * Support for AAG Cloud Watcher station (3rd Party).
  * Support for MoonLite focusers.
  * Support for Fishcamp CCDs (3rd Party).
  * Support for Imager Agent.
  * Improved EQMod driver including custom parking position.
  * New and updated Astrophysics mount driver.
  * New and updated QHY CCD Driver (3rd Party).
  * New and improved GPhoto driver to support DSLRs.
  * New and updated Video4Linux CCD Driver including support for
    long exposures (LX) and Imaging Source cameras.
  * New and improved Apogee CCD driver.
  * Improved support for SBIG CCDs including ST-I.
  * Updated and improved TCFS Focuser drivers.
  * Drivers migrated to libusb 1.0 framework.
  * Rapid Guide Support for CCD Drivers.
  * Improved compatibility with Mac OSX including INDI Server and
    GUI.
  * Various bug fixes and improvements.
- Added new build requirements gsl-devel and libjpeg-devel.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Removed libindi-aarch64.patch (fixed upstream).
* Sat Feb  1 2014 hrvoje.senjan@gmail.com
- Update to version 0.9.7:
  * Support for EQMod mount driver (3rd party).
  * Support for ATIK CCDs and Filter Wheels (3rd party).
  * Support for Shoestring Astronomy FCUSB (3rd party).
  * Support for joysticks and game pads under Linux.
  * LX200, Celeston, and EQMod drivers support joystick input.
  * Improved LX200 & Celestron telescope drivers.
  * Improved simulator drivers.
  * INDI server support for multiple devices per driver.
  * New universal logging and debugging framework for INDI
    developers.
  * Fixed an issue in TCFS driver where a connect may fail if
    focuser is put into sleep mode.
  * Fixed an issue where the client thread in INDI::BaseClient
    is not being terminated gracefully in blocking mode.
  * Fixed an issue involving non-English clients that utilize
    INDI client library to communicate with INDI server.
  * Fixed an issue where some properties in some drivers are
    sent before getting defined by INDI.
- Droped udev_rules_dir_configurable.patch, not required anymore
- Adjust no-return-in-nonvoid-function.patch for this release
* Wed Mar 27 2013 schwab@suse.de
- libindi-aarch64.patch: No port I/O on aarch64
* Wed Nov 28 2012 asterios.dramis@gmail.com
- Update to version 0.9.6:
  * Support for Starlight Xpress Adaptive Optics unit.
  * Improved support for Startlight Xpress CCDs and Filter wheels.
  * Support for Arduino boards, with customizable drivers for common
    observatory auxiliary devices.
  * Support for GPUSB Guide Port Interface.
  * Improved support for QSI CCDs and Filter wheels.
  * Support for filters with absolute positioning.
  * Support for cameras with guiding chip.
  * Fixed INDI server FIFO CPU utilization bug.
  * Fixed various bugs with v4l drivers due to code regression.
  * Improved support for Mac OS X.
  * Improved simulators.
  * _REQUEST properties are now deprecated.
  * Updated tutorials and API.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Added a patch (udev_rules_dir_configurable.patch) to make
  "UDEVRULES_INSTALL_DIR" configurable.
- Added pkgconfig(udev) as build requirement in order to install the udev rules
  file in the correct directory.
* Thu Sep 27 2012 asterios.dramis@gmail.com
- Update to version 0.9.5:
  * Focuser simulator driver.
  * CCD, Telescope, Focuser, and Filter simulators improvements including
    periodic error effects, FWHM, and more.
  * Major improvements to INDI Base Library and INDI Client Library.
  * Fixed minor bugs in LX200 Generic, LX200 FS2, Magellan, and Celestron
    drivers.
  * Minor bugfixes and improvements.
  * Fixed color buffer problem in V4L drivers.
  * Numerous bug fixes and minor improvements.
  From 0.9.1:
  * Bugfix release.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Removed libindi-usleep.patch that fixed compilation with gcc-4.7 (fixed
  upstream).
* Tue May 22 2012 asterios.dramis@gmail.com
- Removed cfitsio_link_libs.patch (not needed after the update of cfitsio
  package and cfitsio.pc fix regarding library linking).
* Wed Mar 14 2012 asterios.dramis@gmail.com
- Added a patch (taken from Fedora) to fix compilation with gcc-4.7.
* Thu Jan 19 2012 asterios.dramis@gmail.com
- Update to version 0.9:
  * INDI::Base drivers are now used for most classes of astronomical
    instruments.
  * New iEQ45 GoTo German Equatorial Mount Driver.
  * New improved QSI CCD & Filter driver.
  * New improved Starlight Xpress CCD & Filter driver.
  * New improved RoboFocus driver.
  * libboost is no longer required to build libindi.
  * Improved support for building on non-Linux OSes.
  * Numerous bug fixes and minor improvements.
- Removed the following patches:
  * bufferoverflowstrncat.patch (fixed upstream).
  * fix_symlinks.patch (fixed upstream).
  * libindi.pc_fix.patch (fixed upstream).
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix a new "no-return-in-nonvoid-function" rpm post-build
  check error.
- Replaced libindi-cfitsio.patch with cfitsio_link_libs.patch (fix missing
  "pthread" in target_link_libraries where needed).
- Spec file updates:
  * Removed boost-devel from BuildRequires (not needed anymore).
* Mon Dec 12 2011 idonmez@suse.com
- Fix build with new cfitsio
* Sun Sep 18 2011 asterios.dramis@gmail.com
- Update to version 0.8:
  * Starlight Xpress CCD and Filter Wheel.
  * EQ Synscan Mount.
  * TCFS Focuser.
  * QSI CCD.
  * Radio Astronomy Supplies Spectracyber Hydrogen Line Spectromet.
  From 0.7.1/0.7.2:
  * Fixed change filter bug in true technology filter wheel.
  * setINDI updated and improved.
  * Improved INDI::Mediator functionality.
  * Fixed buffer reading in INDI::BaseClient.
  * Add new tutorial for INDI::BaseClient.
  From 0.7.0:
  * Dynamic renaming of drivers upon run time.
  * Standard helper API to create and utilize INDI clients.
  * Ability to load driver properties from an external XML file.
  * Ability to write/read XML configuration files for driver values to be
    loaded at run time.
  * Facilitating debugging and simulation of drivers.
  * New C++ framework to facilitate the development of new INDI drivers.
  * New 3rd party drivers!
  * Several bug fixes for current drivers and framework.
- Spec file updates:
  * Added boost-devel in BuildRequires.
- Added 2 patches to fix rpm post-build check errors "bufferoverflowstrncat"
  and "no-return-in-nonvoid-function".
* Sat May 21 2011 asterios.dramis@gmail.com
- Update to version 0.6.2:
  * Build related updates.
  From 0.6.1:
  * Updating drivers.xml to comply to new XML structure for group and devices
    metadata descriptions.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changes in Url, Group, Summary and %%description.
  * Changes in the fix for lib64 installation.
  * Minor other updates.
- Added 2 patches to fix the symlinks installation and the pkgconfig file based
  on Gentoo.
* Thu Apr  1 2010 llunak@novell.com
- Add libfli as a buildrequire
* Fri Mar 20 2009 crrodriguez@suse.de
- run ldconfig
- use RPM_OPT_FLAGS
- fix -devel package dependencies
* Tue Jan  6 2009 dmueller@suse.de
- Initial package (v0.6)
